IL-2 FB Dedicated Server Middleware
===================================

[![Build Status](https://travis-ci.org/IL2HorusTeam/il2ds-middleware.png)](https://travis-ci.org/IL2HorusTeam/il2ds-middleware)
[![Coverage Status](https://coveralls.io/repos/IL2HorusTeam/il2ds-middleware/badge.png)](https://coveralls.io/r/IL2HorusTeam/il2ds-middleware)
[![PyPi package](https://badge.fury.io/py/il2ds-middleware.png)](http://badge.fury.io/py/il2ds-middleware/)
[![Downloads](https://pypip.in/d/il2ds-middleware/badge.png)](https://crate.io/packages/il2ds-middleware/)

Python library which provides high-level access to IL-2 FB Dedicated Server


Installation
------------

    pip install il2ds-middleware

